@@ -1,4 +1,4 @@
-"lkappa" <-
+lkappa <-
 function(r, type="Cohen", weights="squared") 
 {
     nrater <- dim(r)[2]
@@ -12,4 +12,3 @@ function(r, type="Cohen", weights="squared")
     }
     return(mean(kappas))
 }
-
