@@ -1,4 +1,4 @@
-"sphpca" <-
+sphpca <-
 function(datafile, h=0, v=0, f=0, cx=0.75, nbsphere=2, back=FALSE, input="data",method="approx", maxiter=500, output=FALSE)
 {
 
@@ -27,7 +27,7 @@ if (method=="exact")
     {
     lo <- load
     dim(lo) <- c(3*p,1)
-    fn <- function(tt)
+    fn1 <- function(tt)
       {
       dim(tt) <- c(p,3)
       stress <- 0
@@ -42,11 +42,11 @@ if (method=="exact")
         }
       stress
       }
-    opt <- optim(lo,fn,method="BFGS",control=list(maxit=20))
+    opt <- optim(lo,fn1,method="BFGS",control=list(maxit=20))
     convergence <- opt$convergence
     looptim <- opt$par
-    stress.optim <- fn(looptim)
-    stress.non.optim <- fn(lo)
+    stress.optim <- fn1(looptim)
+    stress.non.optim <- fn1(lo)
     load <- looptim
     dim(load) <- c(p,3)
     }
@@ -77,7 +77,7 @@ if (method=="dist" | method=="rscal")
     dim(o) <- c(2*p,1)
     if(method=="dist") d <- sqrt(2*(1-matcorp))
     if(method=="rscal") d <- pi/2*(1-matcorp)
-    fn <- function(ov)
+    fn2 <- function(ov)
       {
       dim(ov) <- c(p,2)
       m <- t(apply(ov,1,o.to.m))
@@ -90,13 +90,13 @@ if (method=="dist" | method=="rscal")
         }}
       stress
       }
-    opt <- optim(o,fn,method="BFGS",control=list(maxit=maxiter))
+    opt <- optim(o,fn2,method="BFGS",control=list(maxit=maxiter))
     convergence <- opt$convergence
     ooptim <- opt$par
     denom <- 1
     if (method=="dist") denom <- sum((2*asin(d/2))^2)
-    stress.optim <- fn(ooptim)/denom
-    stress.non.optim <- fn(o)/denom
+    stress.optim <- fn2(ooptim)/denom
+    stress.non.optim <- fn2(o)/denom
     dim(ooptim) <- c(p,2)
     load <- t(apply(ooptim,1,o.to.m))
     resid.r <- matcorp
